@@ -22,8 +22,8 @@ def copytree(src, dst, symlinks=False, ignore=None):
 
 if __name__ == '__main__':
     # read parameter 
-    app_name = get(sys.argv, 0, default='app') 
-    app_dir = get(sys.argv, 1, default=os.getcwd()) 
+    app_name = get(sys.argv, 1, default='app') 
+    app_dir = get(sys.argv, 2, default=os.getcwd()) 
 
     # check
     app_path = os.path.join(app_dir, app_name)
@@ -34,9 +34,13 @@ if __name__ == '__main__':
         os.mkdir(app_path)
         try : 
             pkgdir = sys.modules['scaffold'].__path__[0]
-            source_path = os.path.join(pkgdir, 'base/*')
+            source_path = os.path.join(pkgdir, 'base')
             copytree(source_path, app_path)
             print("[INFO] Generating Flask Scaffoling Base Completed!")
         except  Exception as e:
-            print("[ERROR]", e)    
-
+            print("[ERROR]", e) 
+    else : 
+        if app_path_exist :
+            print("[ERROR] cannot creating app directory path %s exist." % app_path) 
+        if not base_path_valid :  
+            print("[ERROR] cannot creating base directory path %s not found." % app_dir) 
